#include "IZ_keyboard.h"

void IZ_HandleKeyboardEvents(SDL_Event e, IZ_KeyboardState* state, IZ_Action* action) {
	for (uint8_t i = 0; i < CONTROLS; i += 1) {
		if (e.key.keysym.sym == state->config.control_mapping[i]) {
			const uint16_t bitflag = (0x1 << i);
			if (e.type == SDL_KEYDOWN) {
				*action |= bitflag;
				return;
			}
			if (e.type == SDL_KEYUP) {
				*action &= ~bitflag;
				return;
			}
		}
	}
}

IZ_ProcedureResult IZ_SaveKeyboardConfig(const char* config_path, IZ_KeyboardConfig* config, uint8_t player_index) {
	char keyboard_section_name[26];
	sprintf_s(keyboard_section_name, 26, "Keyboard.%d.ControlMapping", player_index);
	for (uint8_t i = 0; i < CONTROLS; i += 1) {
		if (!ini_puts(
			keyboard_section_name,
			ACTION_NAMES[i],
			SDL_GetKeyName(config->control_mapping[i]),
			config_path)
		) {
			return 1;
		}
	}

	return 0;
}

void IZ_LoadKeyboardConfig(const char* config_path, IZ_KeyboardConfig* config, uint8_t player_index) {
	char buffer[128];
	char keyboard_section_name[26];
	sprintf_s(keyboard_section_name, 26, "Keyboard.%d.ControlMapping", player_index);
	for (uint8_t i = 0; i < CONTROLS; i += 1) {
		ini_gets(
			keyboard_section_name,
			ACTION_NAMES[i],
			SDL_GetKeyName(IZ_DEFAULT_KEYBOARD_CONTROLS[player_index][i]),
			buffer,
			128,
			config_path
		);

		config->control_mapping[i] = SDL_GetKeyFromName(buffer);
	}
}
